/*
 * Copyright (c) 2018, Oracle and/or its affiliates. All rights reserved.
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS FILE HEADER.
 *
 * This code is free software; you can redistribute it and/or modify it
 * under the terms of the GNU General Public License version 2 only, as
 * published by the Free Software Foundation.
 *
 * This code is distributed in the hope that it will be useful, but WITHOUT
 * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
 * version 2 for more details (a copy is included in the LICENSE file that
 * accompanied this code).
 *
 * You should have received a copy of the GNU General Public License version
 * 2 along with this work; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
 *
 * Please contact Oracle, 500 Oracle Parkway, Redwood Shores, CA 94065 USA
 * or visit www.oracle.com if you need additional information or have any
 * questions.
 */

import jdk.testlibrary.Utils;
import jdk.testlibrary.containers.Common;
import jdk.testlibrary.containers.DockerRunOptions;
import jdk.testlibrary.containers.DockerTestUtils;

/*
 * @test
 * @summary Test JDK Metrics class when running inside docker container
 * @library /lib/testlibrary
 * @build MetricsMemoryTester
 * @run main/timeout=360 TestDockerMemoryFailCount
 */

public class TestDockerMemoryFailCount {
    private static final String imageName = Common.imageName("metrics-memory");

    public static void main(String[] args) throws Exception {
        if (!DockerTestUtils.canTestDocker()) {
            return;
        }

        // These tests create a docker image and run this image with
        // varying docker memory options.  The arguments passed to the docker
        // container include the Java test class to be run along with the
        // resource to be examined and expected result.

        DockerTestUtils.buildJdkDockerImage(imageName, "Dockerfile-BasicTest", "jdk-docker");
        try {
            testMemoryFailCount("20m");

        } finally {
            DockerTestUtils.removeDockerImage(imageName);
        }
    }

    private static void testMemoryFailCount(String value) throws Exception {
        Common.logNewTestCase("testMemoryFailCount" + value);
        DockerRunOptions opts =
                new DockerRunOptions(imageName, "/jdk/bin/java", "MetricsMemoryTester");
        opts.addDockerOpts("--volume", Utils.TEST_CLASSES + ":/test-classes/")
                .addDockerOpts("--memory=" + value)
                .addJavaOpts("-cp", "/test-classes/")
                .addClassOptions("failcount");
        DockerTestUtils.dockerRunJava(opts).shouldHaveExitValue(0).shouldContain("TEST PASSED!!!");
    }
}
